;;; site-start.el - loaded at startup before "~/.xemacs/init.el"
;;;
;;; The "-no-site-file" option to xemacs prevents this file from being loaded.

;; fix default info path
(setq Info-directory-list '("/usr/share/info/"
			    "/usr/share/xemacs/xemacs-packages/info/"
			    "/usr/share/xemacs/mule-packages/info/"))

;;; psgml catalog list
(setq sgml-catalog-files
	      (if (getenv "SGML_CATALOG_FILES")
		  (split-path (getenv "SGML_CATALOG_FILES"))
		(list "CATALOG" "catalog"
		      "/etc/sgml/catalog"
		      "/etc/xml/catalog"
		      (locate-data-file "CATALOG"))))

;; default to non-kerberos ftp
(setq efs-ftp-program-name "/usr/bin/ftp")

;; load .el files in "site-start.d/"
(let ((files (directory-files "/usr/share/xemacs/site-packages/lisp/site-start.d" t "\\.el$")))
  (mapc 'load-file files))

;; fix default courier italics
;; for courier, oblique usually produces better results than italic
(setq try-oblique-before-italic-fonts t)
(when window-system
  (make-face-italic 'italic)
  (make-face-italic 'bold-italic))

;; setup coding-systems
(when (featurep 'mule)
  (let* ((locale (or (getenv "LC_ALL")
		   (getenv "LC_CTYPE")
		   (getenv "LANG")))
       (lang-region (and locale
			 (substring locale 0 (min 5 (length locale)))))
       (lang (and lang-region
		  (substring lang-region 0 (min 2 (length lang-region))))))
  (cond ((equal lang "ja")
	 (set-language-environment "Japanese"))
	((equal lang "ko")
	 (set-language-environment "Korean"))
	((equal lang-region "zh_CN")
	 (set-language-environment "Chinese-GB"))
	((equal lang-region "zh_TW")
	 (set-language-environment "Chinese-BIG5")))
  (cond ((and locale (string-match "UTF-8" locale))
	 (require 'un-define)
	 (set-default-coding-systems 'utf-8)
	 (set-coding-priority-list '(utf-8))
	 (set-coding-category-system 'utf-8 'utf-8))
	((equal lang "ja")
	 (set-default-coding-systems 'euc-jp))
	((equal lang "ko")
	 (set-default-coding-systems 'euc-kr))
	((equal lang-region "zh_CN")
	 (set-default-coding-systems 'cn-gb-2312))
	((equal lang-region "zh_TW")
	 (set-default-coding-systems 'big5)))
  ;; register available Input Methods
  (load "leim-list")
  (when (member lang '("ja" "ko" "zh"))
    ;; ispell doesn't support CJK
    (setq-default ispell-local-dictionary "english"))))

;; try to preserve user/group when saving files
(setq-default backup-by-copying-when-mismatch t)

;; when saving a buffer always end it with a newline
(setq-default require-final-newline t)

